using Avalonia;
using Avalonia.Controls;
using Avalonia.Markup.Xaml;

using AvaloniaCoreRTDemo.Controls;
using AvaloniaCoreRTDemo.Interfaces;
using AvaloniaCoreRTDemo.Windows.ViewModels;

namespace AvaloniaCoreRTDemo.Windows;

public sealed partial class MainWindow : Window, IMainWindow
{
    private readonly Application? _app = Application.Current;

    private MainControl MainController => this.GetControl<MainControl>("MainControl");

    public MainWindow() : this(default) { }

    public MainWindow(IMainWindow? window)
    {
        InitializeComponent(window);
#if DEBUG
        this.AttachDevTools();
#endif
    }

    IThemeSwitch IMainWindow.ThemeSwitch => (IThemeSwitch)_app!;
    IMainWindowState IMainWindow.Model => (IMainWindowState)this.MainController.DataContext!;
    PixelPoint IMainWindow.Position => Utilities.GetWindowPosition(this);
    Size IMainWindow.ClientSize => ClientSize;
    Size? IMainWindow.FrameSize => FrameSize;
    WindowState IMainWindow.State => WindowState;

    private void InitializeComponent(IMainWindow? window)
    {
        AvaloniaXamlLoader.Load(this);
        DataContext = new MainViewModel<MainWindow>(this);
        if (window is not null)
        {
            this.MainController.Reload(window.Model);
            WindowStartupLocation = WindowStartupLocation.Manual;
            WindowState = window.State;
            Position = window.Position;
            FrameSize = window.FrameSize;
            ClientSize = window.ClientSize;
        }
    }
}