﻿using System.Runtime.InteropServices;

using Avalonia.Media.Imaging;
using MvvmGen;

namespace AvaloniaCoreRTDemo.Windows.ViewModels;

internal record SystemDetail(string Key, string Value);

[ViewModel]
internal sealed partial class AboutViewModel
{
    private readonly IBitmap _computerImage;
    private readonly bool _darkTheme;

    public IBitmap ComputerImage => _computerImage;

    public IReadOnlyList<SystemDetail> SystemDetails { get; } =
        new[]
        {
            new SystemDetail("Number of Cores", Environment.ProcessorCount.ToString()),
            new SystemDetail("OS", RuntimeInformation.OSDescription),
            new SystemDetail("OS Arch", RuntimeInformation.OSArchitecture.ToString()),
            new SystemDetail("OS Version", Environment.OSVersion.ToString()),
            new SystemDetail("Computer", Environment.MachineName),
            new SystemDetail("User", Environment.UserName),
            new SystemDetail("System Path", Environment.SystemDirectory),
            new SystemDetail("Current Path", Environment.CurrentDirectory),
            new SystemDetail("Process Arch", RuntimeInformation.ProcessArchitecture.ToString()),
            new SystemDetail("Runtime Name", RuntimeInformation.FrameworkDescription),
            new SystemDetail("Runtime Path", RuntimeEnvironment.GetRuntimeDirectory()),
            new SystemDetail("Runtime Version", RuntimeEnvironment.GetSystemVersion()),
            new SystemDetail("Framework Version", Environment.Version.ToString()),
        };

    private string ComputerImageName
    {
        get
        {
            if (Utilities.IsWindows)
                return !_darkTheme ? "windows.png" : "windows_d.png";
            else if (Utilities.IsOSX)
                return !_darkTheme ? "macos.png" : "macos_d.png";
            else
                return !_darkTheme ? "linux.png" : "linux_d.png";
        }
    }

    public AboutViewModel(bool darkTheme) : this()
    {
        _darkTheme = darkTheme;
        _computerImage = Utilities.GetImageFromResources(ComputerImageName);
    }

    ~AboutViewModel()
    {
        _computerImage.Dispose();
    }
}