﻿using Avalonia.Controls;

using AvaloniaCoreRTDemo.Interfaces;
using MvvmGen;

namespace AvaloniaCoreRTDemo.Windows.ViewModels;

[ViewModel]
internal abstract partial class ApplicationModelBase
{
    private readonly IThemeSwitch _themeSwitch;

    [Property]
    private bool _aboutEnabled = true;

    [Property]
    private bool _defaultLightEnabled = false;

    [Property]
    private bool _defaultDarkEnabled = false;

    [Property]
    private bool _fluentLightEnabled = false;

    [Property]
    private bool _fluentDarkEnabled = false;

    public ApplicationModelBase(IThemeSwitch themeSwitch) : this()
    {
        _themeSwitch = themeSwitch;
        IntializeTheme(themeSwitch.Current);
    }

    [Command]
    protected abstract void HelpAbout();

    [Command]
    protected abstract void DefaultLight();

    [Command]
    protected abstract void DefaultDark();

    [Command]
    protected abstract void FluentLight();

    [Command]
    protected abstract void FluentDark();

    protected async void RunHelpAbout(Window currentWindow)
    {
        if (AboutEnabled)
            try
            {
                AboutEnabled = false;
                await new AboutWindow(IsDarkTheme(_themeSwitch.Current)).ShowDialog(currentWindow);
            }
            finally
            {
                AboutEnabled = true;
            }
    }

    protected void SetTheme(ApplicationTheme theme)
    {
        IntializeTheme(theme);
        _themeSwitch.ChangeTheme(theme);
    }

    [Command]
    private void FileExit() => Environment.Exit(0);

    private void IntializeTheme(ApplicationTheme theme)
    {
        DefaultLightEnabled = theme != ApplicationTheme.SimpleLight;
        DefaultDarkEnabled = theme != ApplicationTheme.SimpleDark;
        FluentLightEnabled = theme != ApplicationTheme.FluentLight;
        FluentDarkEnabled = theme != ApplicationTheme.FluentDark;
    }

    private static bool IsDarkTheme(ApplicationTheme? theme) =>
        theme switch
        {
            ApplicationTheme.SimpleDark => true,
            ApplicationTheme.FluentDark => true,
            _ => false,
        };
}